##############################################################################
#
# Copyright (c) 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################
__doc__="""VerboseSecurity product.

$Id: __init__.py,v 1.3 2004/06/17 02:38:44 shane Exp $
"""

import os
from VerboseSecurityPolicy import VerboseSecurityPolicy

if os.environ.get('ZOPE_VERBOSE_SECURITY', '1'):
    from AccessControl.SecurityManager import setSecurityPolicy
    setSecurityPolicy(VerboseSecurityPolicy())
    import PermissionRolePatch
